# bamtools

**DOI:** [10.5281/zenodo.7345681](https://doi.org/10.5281/zenodo.7345681)

## Available Versions
- **Version 2.5.2**
  - [Download](https://zenodo.org/record/10211475/files/bamtools_2.5.2.img)
  - **MD5:** `fb194b8ae6335eb2e88cb62e0e8aedf7`
  - **DOI:** [10.5281/zenodo.10211475](https://doi.org/10.5281/zenodo.10211475)
  - **Size:** 99.53 MB
  - **Binaries:** 0 available

## Binaries (1 total)

```bamtools```
